@@ -1,15 +1,15 @@
 ﻿import asyncio
-from MetaRpcMT4.mt4_account import MT4Account
+from MetaRpcMT5.mt5_account import MT5Account
 
 
 async def test_account_summary():
-    user = 910798516
-    password = "bzen2yz"
-    host = "18.163.180.152"
+    user = 5036292718
+    password = "_0AeXaFk"
+    host = "78.140.180.198"
     port = 443
-    server_name = "VTMarkets-Demo"
+    server_name = "MetaQuotes-Demo"
 
-    account = MT4Account(user=user, password=password)
+    account = MT5Account(user=user, password=password)
     #await account.connect_by_host_port(host=host, port=port, base_chart_symbol="EURUSD")
     await account.connect_by_server_name(server_name=server_name, base_chart_symbol="EURUSD")
 
@@ -17,9 +17,7 @@ async def test_account_summary():
     print("✅ Account summary:")
     print(summary)
 
-    some  = await account.quote("sadfsf");
-
-    async for tick in account.on_symbol_tick(["EURUSD", "GBPUSD", "BTCUSD"]):
+    async for tick in account.on_symbol_tick(["EURUSD", "GBPUSD"]):
         print(tick)
 
 
